==> aeron-all-1.21.2-sources.jar: io/aeron/driver/SubscriberPosition.java <==
/*
 * Copyright 2014-2019 Real Logic Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.aeron.driver;

import org.agrona.concurrent.status.Position;

/**
 * Consumption position a subscriber has got to within a {@link SubscriptionLink}.
 */
public final class SubscriberPosition
{
    private final SubscriptionLink subscriptionLink;
    private final Subscribable subscribable;
    private final Position position;

    public SubscriberPosition(
        final SubscriptionLink subscriptionLink, final Subscribable subscribable, final Position position)
    {
        this.subscriptionLink = subscriptionLink;
        this.subscribable = subscribable;
        this.position = position;
    }

    public Position position()
    {
        return position;
    }

    public int positionCounterId()
    {
        return position().id();
    }

    public SubscriptionLink subscription()
    {
        return subscriptionLink;
    }

    public Subscribable subscribable()
    {
        return subscribable;
    }

    public void addLink(final PublicationImage image)
    {
        subscriptionLink.link(image, position);
    }
}

==> aeron-all-1.32.0-sources.jar: io/aeron/driver/SubscriberPosition.java <==
/*
 * Copyright 2014-2021 Real Logic Limited.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.aeron.driver;

import org.agrona.concurrent.status.Position;

/**
 * Consumption position a subscriber has got to within a {@link SubscriptionLink}.
 */
final class SubscriberPosition
{
    private final SubscriptionLink subscriptionLink;
    private final Subscribable subscribable;
    private final Position position;

    SubscriberPosition(
        final SubscriptionLink subscriptionLink, final Subscribable subscribable, final Position position)
    {
        this.subscriptionLink = subscriptionLink;
        this.subscribable = subscribable;
        this.position = position;
    }

    Position position()
    {
        return position;
    }

    int positionCounterId()
    {
        return position().id();
    }

    SubscriptionLink subscription()
    {
        return subscriptionLink;
    }

    Subscribable subscribable()
    {
        return subscribable;
    }

    void addLink(final PublicationImage image)
    {
        subscriptionLink.link(image, position);
    }

    public String toString()
    {
        return "SubscriberPosition{" +
            "subscriptionLink=" + subscriptionLink +
            ", subscribable=" + subscribable +
            ", position=" + position +
            '}';
    }
}
